#!/bin/bash

#############################################################################

### OBJECTIVE:
## Create the .gpf and .dpf files to run the ADT4 Database calculation.
## Run AutoDock4.

#############################################################################

### VARIABLES:
ADTPYTHON=/PATH-TO-ADTools/mgltools_x86_64Linux2_1.5.6/bin/pythonsh
ADTTOOLS=/PATH-TO-ADTools/mgltools_x86_64Linux2_1.5.6/MGLToolsPckgs/AutoDockTools/Utilities24
ADT4=/PATH-TO-ADT4/Autodock4/x86_64Linux2

#############################################################################

### SCRIPT:

## Go to the DTB_screening directory
cd ../DTB_screening

## Create and enter the folder where the docking maps will be stored
mkdir -p maps_docking
cd maps_docking

## Do a symbolic link of the Protein pdbqt file previously created
ln -s ../../Protein/6y2g_protein_A.pdbqt .

## Create the grid parameter file for AutoGrid4 using the command line and the GUI interface of ADTtools
## Open the protein (6y2g_protein_A.pdbqt) in the AutoDockTools GUI interface: adt 6y2g_protein_A.pdbqt
## Go to the left side panel of the interface and choose the "R" representation, instead of the default "L" representation
## Click on Grid tab, and then on GridBox. A Grid Options window will pop up. Since we are defining a grid box to be used in AutoDock4, we need to make sure that the Spacing (angstrom) is set to 0.375
## Now we alter the Current Total Grid Points per map in each dimension, and the Center Grid Box, so that the Grid covers the desired binding site
## After defining the grid we need to insert this information (center and size of the grid) using the command that takes advantage of the python tool prepare_gpf4.py from ADTools:
${ADTPYTHON} ${ADTTOOLS}/prepare_gpf4.py -r 6y2g_protein_A.pdbqt -d ../../DTB_compounds/CHEMBL_PDBQT/ -p npts='78,94,80' -p gridcenter='-22.472,4.639,-20.889' -o grid.gpf

## Now, create the grid maps
${ADT4}/autogrid4 -p grid.gpf -l grid.glg

## Go back to the DTB_screening directory 
cd ..

## Create and enter the folder where the docking results will be run and stored
mkdir ADT4
cd ADT4

## List all the ligands used in the screening campaign which can be found in the DTB_compounds/CHEMBL_SDF folder
for compound in $(ls ../../DTB_compounds/CHEMBL_SDF/*.sdf | sed s/.sdf//g)
do
    ## Create a folder for every ligand in the DTB_screening/ADT4 directory
    mkdir -p ${compound}

    ## Enter in each of the dedicated folders to run the docking calcultion
    cd ${compound}
    
    ## Do a symbolic link of the target ligand and protein previously created and of all the necessary grid files
    ln -s ../../../DTB_compounds/CHEMBL_PDBQT/${compound}.pdbqt .
    ln -s ../../../Protein/6y2g_protein_A.pdbqt .
    ln -s ../../maps_docking/*map* .
    
    ## Create the docking parameter file for AutoDock4
    $ADTPYTHON $ADTTOOLS/prepare_dpf4.py -l ${compound}.pdbqt -r 6y2g_protein_A.pdbqt
    ## Run AutoDock4
    echo 'Please be patient, as this might take a while.' 
    ${ADT4}/autodock4 -p *.dpf -l ${compound}.dlg
    ## Get the lowest energy of binding conformation of the ligand
    $ADTPYTHON $ADTTOOLS/write_lowest_energy_ligand.py -f ${ligand}.dlg -o lowestenergy.pdbqt

    cd ..
done

## Go back to the scripts directory
cd ../../scripts

## END of the script
