#!/bin/bash

#############################################################################

### OBJECTIVE:
## Adapt the config.txt file for the VINA run.
## Run AutoDock Vina.

#############################################################################

### VARIABLES:
VINA=/PATH-TO-VINA/vina

#############################################################################

### SCRIPT:

## Go to the DTB_screening directory
cd ../DTB_screening

## Create and enter the folder where the docking results will be stored
mkdir -p VINA
cd VINA


## Create the config.txt file
## Open the protein (6y2g_protein_A.pdbqt) in AutoDockTools: /home/bvictor/Programs/mgltools_x86_64Linux2_1.5.6/bin/adt 6y2g_protein_A.pdbqt
## On AutoDockTools GUI go to the left side and choose the "R" representation, instead of the default "L" representation
## Then click on Grid, then GridBox. A Grid Options windows will show up. Since we are defining a grid box to be used in AutoDock VINA, we need to make sure that the Spacing (angstrom) is set to 1.000
## Now we alter the Current Total Grid Pts per map in each dimension, and the Center Grid Box, so that the Grid covers the desired binding site
## After defining the grid we need to create a config.txt file with this information (center and size of the grid)
## This config.txt file can be used as input of all the docking calculations. There is no need to create one config.txt file specific for each ligand docking run. 

echo "center_x = -22.472
center_y = 3.806
center_z = -23.306 
    
size_x = 26
size_y = 32
size_z = 34" > config.txt


## Go through the name of every ligand in the DTB_compounds/CHEMBL_SDF directory
for compound in $(ls ../../DTB_compounds/CHEMBL_SDF/*.sdf | sed s/.sdf//g)
do

    ## Create a folder for every ligand in the DTB_screening/ADT4 directory
    mkdir -p ${compound}

    ## Enter in each of the dedicated folders to run the docking calcultion
    cd ${compound}

    # Create the necessary symbolic links to the files necessary to run the docking calculations 
    ln -s ../../../DTB_compounds/CHEMBL_PDBQT/${compound}.pdbqt .
    ln -s ../../../Protein/6y2g_protein_A.pdbqt .

    ## Running VINA
    ## Get the ligand pdbqt file
    ${VINA} --config ../config.txt --receptor 6y2g_protein_A.pdbqt --ligand ${compound}.pdbqt --log ${compound}.log --out ${compound}_out.pdbqt

    cd ..

done

## Go back to the scripts directory
cd ../../scripts

## END of the script
