#!/bin/bash

#############################################################################

### OBJECTIVE:
##  Prepare the 3D files of the compounds database, so that the .pdbqt files of all compounds are generated.

#############################################################################

### VARIABLES:
MAYACHEMTOOLS=/PATH-TO-MAYACHEMTOOLS/mayachemtools/bin
Balloon=/PATH-TO-BALLOON/Balloon/balloon
ADTPYTHON=/PATH-TO-ADTools/mgltools_x86_64Linux2_1.5.6/bin/pythonsh
ADTTOOLS=/PATH-TO-ADTools/mgltools_x86_64Linux2_1.5.6/MGLToolsPckgs/AutoDockTools/Utilities24
OPENBABEL=/PATH-TO-OPENBABEL/obabel

#############################################################################

### SCRIPT:

## Go to the DTB_compounds directory
cd ../DTB_compounds

## Go to https://www.ebi.ac.uk/chembl/g/#browse/activities/filter/target_chembl_id%3ACHEMBL3927 on the left select "Ki", then select all molecules, and finally download the .csv file

## Replace every ";" with "," in the .csv file. This step is required since
## Datawarrior can only identify different columns is they are separated by
## commas (,). This can be achieved using a command line approach using the
## following sed command
## sed -i 's/;/,/g' SARS-CoV-2_ligands.csv

## Open the .csv file with DataWarrior, go to Data, Delete Rows, Duplicate Rows, and select Molecule CHEMBL ID. Then go to File, Save Special, SD-file, and select Atom coordinates 2D, and Compound name column Molecule CHEMBL ID.

## Create the folders where the .sdf, .mol2, and .pdbqt files will be stored, respectively
mkdir -p CHEMBL_SDF CHEMBL_MOL2 CHEMBL_PDBQT

## Split the sdf file, into individual sdf files
$MAYACHEMTOOLS/SplitSDFiles.pl -m Cmpds --numcmpds 1 -c MolName -o SARS-CoV-2_ligands.sdf 

## Move the all the .sdf file to the previously created directory
mv CHEMBL*.sdf ./CHEMBL_SDF

## Get the ligand .sdf file
for file_sdf in $(ls ./CHEMBL_SDF/*.sdf)
do
    ## Remove the ".sdf" file extension
    file="$(basename ${file_sdf} .sdf)"
    ## Create a 3D conformation of each ligand and convert the file from a .sdf format to .mol2
    $Balloon -H --input-file ./CHEMBL_SDF/${file}.sdf --output-file ./CHEMBL_MOL2/${file}.mol2
    ## Convert the ligand from a .mol2 file to a .pdbqt file, while adding hydrogens
    $ADTPYTHON $ADTTOOLS/prepare_ligand4.py -A hydrogens -l ./CHEMBL_MOL2/${file}.mol2 -o ./CHEMBL_PDBQT/${file}.pdbqt

    #### Alternative this last step can be performed using openbabel
    #### using the command:
    #### ${openbabel} ./CHEMBL_MOL2/${file}.mol2 --partialcharge gasteiger -O ./CHEMBL_PDBQT/${file}.pdbqt


done

## Go back to the scripts directory
cd ../scripts
