#!/bin/bash

#############################################################################

### OBJECTIVE:
## Prepare the files to analyse the results obtained with AutoDock4.

#############################################################################

## Switch command output language from native language to english
LANG=en_US

#############################################################################

### SCRIPT:

## Go to the DTB_screening/ATD4 directory
cd ../DTB_screening/ADT4

receptor=6y2g_protein_A

## Go through every folder in the current directory
for Ligand in $(ls -d *)
do

    cd $Ligand
    
    ## Print the ligand name and corresponding lowest binding energy into a temporary file
    awk -v var=${Ligand} '/Lowest/ { show[NR+4] = 1 } (NR in show) { printf "%-25s %-45s %-20s \n", var,$3,$5 ; delete show[NR] }' ${Ligand}.dlg >> ../../Results_${receptor}_ADT4.tmp                   

    cd ..
    
done

cd ..

## Get the temporary file
for file_tmp in `ls ./*ADT4.tmp`
do
    ## Remove the ".tmp" file extension  
    file="$(basename ${file_tmp} .tmp)"
    ## Insert a header into the temporary file
    sed -i '1i Ligand:                   Lowest_Binding_Energy_(kcal/mol):             Run:'  ./${file}.tmp
    ## Sort the content of the temporary file, based on the second column, into a new file
    sort -g -k2,2 ./${file}.tmp > ./Sorted_${file}.txt
done

## Remove the temporary file
rm ./*.tmp

## Go back to the scripts directory 
cd ../scripts
