#!/bin/bash

#############################################################################

### OBJECTIVE:
## Create the .gpf and .dpf files to run the ADT4 calculation.
## Run AutoDock4.

#############################################################################

### VARIABLES:
ADTPYTHON=/PATH-TO-ADTools/mgltools_x86_64Linux2_1.5.6/bin/pythonsh
ADTTOOLS=/PATH-TO-ADTools/mgltools_x86_64Linux2_1.5.6/MGLToolsPckgs/AutoDockTools/Utilities24
ADT4=/PATH-TO-ADT4/Autodock4/x86_64Linux2

#############################################################################

### SCRIPT:

## Go to the Validation directory
cd ../Validation

## Create and enter the folder where the docking results will be stored
mkdir ADT4
cd ADT4

## Do a symbolic link of the pdbqt files previously created
ln -s ../../Protein/6y2g_ligand_A.pdbqt .
ln -s ../../Protein/6y2g_protein_A.pdbqt .

## Get the ligand pdbqt file
for ligand_pdbqt in 6y2g_ligand_A.pdbqt
do
    ## Remove the ".pdbqt" file extension
    ligand="$(basename ${ligand_pdbqt} .pdbqt)"
    ## Get the protein pdbqt file
    for receptor_pdbqt in 6y2g_protein_A.pdbqt
    do
	## Remove the ".pdbqt" file extension
        receptor="$(basename ${receptor_pdbqt} .pdbqt)"
	## Create the grid parameter file for AutoGrid4
	## Open the protein (6y2g_protein_A.pdbqt) in AutoDockTools: /home/bvictor/Programs/mgltools_x86_64Linux2_1.5.6/bin/adt 6y2g_protein_A.pdbqt
	## On AutoDockTools GUI go to the left side and choose the "R" representation, instead of the default "L" representation
	## Then click on Grid, then GridBox. A Grid Options windows will show up. Since we are defining a grid box to be used in AutoDock4, we need to make sure that the Spacing (angstrom) is set to 0.375
	## Now we alter the Current Total Grid Pts per map in each dimension, and the Center Grid Box, so that the Grid covers the desired binding site
	## After defining the grid we need to insert this information (center and size of the grid) in the following line
	${ADTPYTHON} ${ADTTOOLS}/prepare_gpf4.py -r ${receptor}.pdbqt -l ${ligand}.pdbqt -p npts='78,94,80' -p gridcenter='-22.472,4.639,-20.889' -o grid.gpf
	## Create the maps
	${ADT4}/autogrid4 -p grid.gpf -l grid.glg
	## Create the docking parameter file for AutoDock4
	$ADTPYTHON $ADTTOOLS/prepare_dpf4.py -l ${ligand}.pdbqt -r ${receptor}.pdbqt
	## Run AutoDock4
	echo 'Please be patient, as this might take a while.' 
        ${ADT4}/autodock4 -p *.dpf -l ${ligand}.dlg
	## Get the lowest energy conformation of the ligand
	$ADTPYTHON $ADTTOOLS/write_lowest_energy_ligand.py -f ${ligand}.dlg -o lowestenergy.pdbqt
    done
done

## Go back to the scripts directory 
cd ../../scripts
