#!/bin/bash

#############################################################################

### OBJECTIVE:
## Create and prepare the config.txt file for the VINA validation calculation.
## Run AutoDock Vina.

#############################################################################

### VARIABLES:
VINA=/PATH-TO-VINA/vina

#############################################################################

### SCRIPT:

## Go to the Validation directory
cd ../Validation

## Create and enter the folder where the docking results will be stored
mkdir VINA
cd VINA

## Do a symbolic link of the pdbqt files previously created
ln -s ../../Protein/6y2g_ligand_A.pdbqt .
ln -s ../../Protein/6y2g_protein_A.pdbqt .

## Create the config.txt file
## Open the protein (6y2g_protein_A.pdbqt) in AutoDockTools: /home/bvictor/Programs/mgltools_x86_64Linux2_1.5.6/bin/adt 6y2g_protein_A.pdbqt
## On AutoDockTools GUI go to the left side and choose the "R" representation, instead of the default "L" representation
## Then click on Grid, then GridBox. A Grid Options windows will show up. Since we are defining a grid box to be used in AutoDock VINA, we need to make sure that the Spacing (angstrom) is set to 1.000
## Now we alter the Current Total Grid Pts per map in each dimension, and the Center Grid Box, so that the Grid covers the desired binding site
## After defining the grid we need to create a config.txt file with this information (center and size of the grid)

echo "center_x = -22.472
center_y = 3.806
center_z = -23.306

size_x = 26
size_y = 32
size_z = 34" > config.txt

## Running VINA
## Get the ligand pdbqt file
for ligand_pdbqt in 6y2g_ligand_A.pdbqt
do
    ## Remove the ".pdbqt" file extension
    ligand="$(basename ${ligand_pdbqt} .pdbqt)"
    ## Get the protein pdbqt file
    for receptor_pdbqt in 6y2g_protein_A.pdbqt
    do
	## Remove the ".pdbqt" file extension
        receptor="$(basename ${receptor_pdbqt} .pdbqt)"
	## Run AutoDock Vina
	${VINA} --config config.txt --receptor ${receptor}.pdbqt --ligand ${ligand}.pdbqt --log ${ligand}.log --out ${ligand}_out.pdbqt
    done
done

## Go back to the scripts directory 
cd ../../scripts

