#!/bin/bash

#############################################################################

### OBJECTIVE:
## Extract, prepare and create the .pdbqt file of the protein used in all ADT4 and VINA calculations.
## Parameterize and create the .pdbqt file of the ligand used to validate the docking protocols.

#############################################################################

### VARIABLES:
Unicon=/PATH-TO-Unicon/Unicon
ADTPYTHON=/PATH-TO-ADTools/mgltools_x86_64Linux2_1.5.6/bin/pythonsh
ADTTOOLS=/PATH-TO-ADTools/mgltools_x86_64Linux2_1.5.6/MGLToolsPckgs/AutoDockTools/Utilities24

#############################################################################

### SCRIPT:

## Go to the Protein directory
cd ../Protein

## Go to www.rcsb.org/structure/6y2g and download the PDB file

## Extract the lines that start with "ATOM", corresponding to the protein, and that correspond to Chain A
egrep " A " 6y2g.pdb | egrep ATOM > 6y2g_protein_A.pdb
echo 'Protein extracted with success!'

## Extract the lines that contain "O6K", corresponding to the ID of the ligand, and that correspond to Chain A
egrep " A " 6y2g.pdb | egrep HETATM | egrep -v HOH | egrep O6K > 6y2g_ligand_A.pdb
echo 'Ligand extracted with success!'

## Convert the ligand from a .pdb file to a .mol2 file, while adding hydrogen
$Unicon -i 6y2g_ligand_A.pdb -g 3 --hydrogen -p single -o 6y2g_ligand_A.mol2
echo 'Conversion of the ligand to mol2 done successfully!'

## Convert the ligand from a .mol2 file to a .pdbqt file
$ADTPYTHON $ADTTOOLS/prepare_ligand4.py -l 6y2g_ligand_A.mol2 -o 6y2g_ligand_A.pdbqt
echo 'Conversion of the ligand to pdbqt done successfully!'

## Convert the protein from a .pdb file to a .pdbqt file, while adding hydrogens
$ADTPYTHON $ADTTOOLS/prepare_receptor4.py -r 6y2g_protein_A.pdb -A hydrogens -o 6y2g_protein_A.pdbqt
echo 'Conversion of the protein to pdbqt done successfully!'

### Additionally OpenBabel can also be used to perform either the conversion of files between the different file formats (as previously mentioned in script_DTB_conversion.sh file). For further details on how to use this software please visit OpenBabel webpage: http://openbabel.org/wiki/Main_Page

## Go back to the scripts directory
cd ../scripts
